summaryrefslogtreecommitdiff
path: root/include/temp_sensor.h
diff options
context:
space:
mode:
authorVic Yang <victoryang@google.com>2012-02-08 14:08:14 +0800
committerVic Yang <victoryang@google.com>2012-02-08 14:53:17 +0800
commit059c633a27ea4475cd9a7b69dbbbf72f5f55e157 (patch)
tree33e4a3412e3963d185f6f1e38511aeb003e738fc /include/temp_sensor.h
parentd3e1de758cfa3a7dd990f0fb63eddbb1ae870418 (diff)
downloadchrome-ec-059c633a27ea4475cd9a7b69dbbbf72f5f55e157.tar.gz
Add tmp006 object temperature calculation
Implement TMP006 object temperature calculation. Also add a console command to calculate temperature with manually entered data. BUG=chrome-os-partner:7801 TEST=In console, "tempremote 29715 -105000 6390" gives 285.00K. Change-Id: I0f9193fb970fdc36566399e7083e73ab58965a85
Diffstat (limited to 'include/temp_sensor.h')
-rw-r--r--include/temp_sensor.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/include/temp_sensor.h b/include/temp_sensor.h
index df937112e1..a89dbe7e5a 100644
--- a/include/temp_sensor.h
+++ b/include/temp_sensor.h
@@ -45,8 +45,11 @@ int temp_sensor_read(enum temp_sensor_id id);
#define TMP006_PORT(ADDR) (ADDR >> 16)
#define TMP006_REG(ADDR) (ADDR & 0xffff)
-/* Read TI TMP006 temperature sensor. Return temperature in K. */
-int temp_sensor_tmp006_read(const struct temp_sensor_t* sensor);
+/* Read TI TMP006 die temperature sensor. Return temperature in K. */
+int temp_sensor_tmp006_read_die_temp(const struct temp_sensor_t* sensor);
+
+/* Read TI TMP006 object temperature sensor. Return temperature in K. */
+int temp_sensor_tmp006_read_object_temp(const struct temp_sensor_t* sensor);
/* Configure TMP006 DRDY pin. */
void temp_sensor_tmp006_config(const struct temp_sensor_t* sensor);